@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use 5.008_001;
 
-use version; our $VERSION = 'v0.9.3';
+use version; our $VERSION = 'v0.9.4';
 
 our @COMMANDS_INFO = (
     +{
@@ -80,6 +80,14 @@ EODESC
         command => 'dump_all',
         summary => 'Dump whole server data',
     },
+    +{
+        command => 'restore_dump',
+        summary => 'Restore data from dump',
+        description => <<'EODESC',
+Usage:
+    > restore_dump FILE
+EODESC
+    },
     +{
         command => 'randomset',
         summary => 'Generate sample data and SET them',
